Dokang
======

Dokang is a lightweight search engine. It comes with a command line
program and a web frontend. It is lightweight in the sense that it is
merely a wrapper around the Whoosh search engine with a very simple
HTML text indexer. It can be extended to retrieve content from other
types of files (such as PDF).

We (Polyconseil) use it to search through the `Sphinx
<http://sphinx-doc.org/>`_-generated documentation of all our
projects.


Topics
------

.. toctree::
   :maxdepth: 2

   basics.rst
   advanced.rst
   extending.rst
   dev.rst
   api.rst
   changes.rst
